#include "clock.hpp"
#include "time.h"
#include "legend.hpp"
#include <string.h>

Clock::Clock(int x, int y, char* title, float offset) :
	Icon(x, y, x + CLOCK_WIDTH, y + CLOCK_HEIGHT)
{
	// make a copy of the button's name
	if (strlen(title) == 0) {
	  title = "Local Time";
	  time_difference = 0;
	}
	// use the requested time zone and difference
	strncpy(time_zone, title, sizeof(time_zone) );
	time_difference = offset;

	// initialize the time
	current_time = 0;

	// create the clock box
	box = new ShadedBox(x1, y1,
			    x2 - x1, y2 - y1,
			    BLACK,
			    BRIGHT_RED,
			    GRAY);
}

void Clock::Display()
{
	// show the backdop box
	box->Display();

	// partition off the legend area
	BOX_TYPE area;
	area.x1 = x1 + 2;
	area.y1 = y1 + CLOCK_LEGEND_HEIGHT + 2;
	area.x2 = x2 - 2;
	area.y2 = area.y1;
	GraphicsHandler->DrawLine(BRIGHT_RED,
				  SOLID_LINE,
				  &area);

	// display the name of the time zone
	Legend time;
	area.y1 = y1;
	time.Center(&area, BRIGHT_RED, time_zone);
}

void Clock::Update()
{
	// display the complete clock if not running
	if (current_time == 0) Display();

	// see if the time has changed
	long new_time = EventsHandler->SystemTime();
	if (new_time == current_time) return;

	// update the time
	current_time = new_time;

	// read the time for our time zone
	char* our_time =
		EventsHandler->CurrentTime(time_difference);

	// don't let mouse interrupts disrupt the
	// process of updating the screen
	EventsHandler->DisableInterrupts();

	// erase the old time
	BOX_TYPE box;
	box.x1 = x1 + 3;
	box.y1 = y1 + CLOCK_LEGEND_HEIGHT + 3;
	box.x2 = x2 - 3;
	box.y2 = y2 - 3;
	GraphicsHandler->FillBox(GRAY, &box);

	// display the current time
	Legend time;
	time.Center(&box, BRIGHT_RED, our_time);

	// display updates: turn on the interrupts
	EventsHandler->EnableInterrupts();
}

Clock::~Clock()
{
	delete box;
}
